EllipticCurve

Enum EllipticCurve 

pub enum EllipticCurve {
    P192,
    P256,
}
Represents supported elliptic curves for cryptographic operations.

The methods that represent operations require the EccBackend to be started before use.

Variants



P192

The P192 elliptic curve, a 192-bit curve.



P256

The P256 elliptic curve, a 256-bit curve.

Implementations

Source

impl EllipticCurve

pub const fn size(self) -> usize

Returns the size of the elliptic curve in bytes.

Source

impl EllipticCurve

pub fn affine_point_multiplication<'op>( self, k: &'op [u8], px: &'op [u8], py: &'op [u8], ) -> Result<EccBackendOperation<'op, AffinePointMultiplication>, KeyLengthMismatch>

Configures a new Base Point Multiplication operation with the given inputs, to be executed on EccBackend.

Outputs need to be assigned separately before executing the operation.

pub fn affine_point_verification<'op>( self, px: &'op [u8], py: &'op [u8], ) -> Result<EccBackendOperation<'op, AffinePointVerification>, KeyLengthMismatch>

Configures a new Base Point Verification operation with the given inputs, to be executed on EccBackend.

Outputs need to be assigned separately before executing the operation.

pub fn affine_point_verification_multiplication<'op>( self, k: &'op [u8], px: &'op [u8], py: &'op [u8], ) -> Result<EccBackendOperation<'op, AffinePointVerificationAndMultiplication>, KeyLengthMismatch>

Configures a new Base Point Verification and Multiplication operation with the given inputs, to be executed on EccBackend.

Outputs need to be assigned separately before executing the operation.

pub fn jacobian_point_multiplication<'op>( self, k: &'op [u8], px: &'op [u8], py: &'op [u8], ) -> Result<EccBackendOperation<'op, JacobianPointMultiplication>, KeyLengthMismatch>

Configures a new Jacobian Point Multiplication operation with the given inputs, to be executed on EccBackend.

Outputs need to be assigned separately before executing the operation.

pub fn jacobian_point_verification<'op>( self, qx: &'op [u8], qy: &'op [u8], qz: &'op [u8], ) -> Result<EccBackendOperation<'op, JacobianPointVerification>, KeyLengthMismatch>

Configures a new Jacobian Point Verification operation with the given inputs, to be executed on EccBackend.

Outputs need to be assigned separately before executing the operation.

pub fn affine_point_verification_jacobian_multiplication<'op>( self, k: &'op [u8], px: &'op [u8], py: &'op [u8], ) -> Result<EccBackendOperation<'op, AffinePointVerificationAndJacobianPointMultiplication>, KeyLengthMismatch>

Configures a new Base Point Verification + Jacobian Point Multiplication operation with the given inputs, to be executed on EccBackend.

Outputs need to be assigned separately before executing the operation.