Ecc

Struct Ecc 

pub struct Ecc<'d, Dm: DriverMode> { /* private fields */ }
The ECC Accelerator driver.

Note that as opposed to commonly used standards, this driver operates on little-endian data.

Implementations

Source

impl<'d> Ecc<'d, Blocking>

pub fn new(ecc: ECC<'d>, config: Config) -> Self

Create a new instance in Blocking mode.

Source

impl<'d, Dm: DriverMode> Ecc<'d, Dm>

pub fn apply_config(&mut self, config: &Config)

Applies the given configuration to the ECC peripheral.

pub fn reset(&mut self)

Resets the ECC peripheral.

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Available on crate feature unstable only.

Register an interrupt handler for the ECC peripheral.

Note that this will replace any previously registered interrupt handlers.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn affine_point_multiplication<'op>( &'op mut self, curve: EllipticCurve, k: &[u8], px: &[u8], py: &[u8], ) -> Result<EccResultHandle<'op, AffinePointMultiplication>, KeyLengthMismatch>

Base Point Multiplication

This operation performs (Qx, Qy) = k * (Px, Py).

Errors

This function will return an error if the bitlength of the parameters is different from the bitlength of the prime fields of the curve.

pub fn affine_point_verification<'op>( &'op mut self, curve: EllipticCurve, px: &[u8], py: &[u8], ) -> Result<EccResultHandle<'op, AffinePointVerification>, KeyLengthMismatch>

Base Point Verification

This operation verifies whether Point (Px, Py) is on the selected elliptic curve.

Errors

This function will return an error if the bitlength of the parameters is different from the bitlength of the prime fields of the curve.

pub fn affine_point_verification_multiplication<'op>( &'op mut self, curve: EllipticCurve, k: &[u8], px: &[u8], py: &[u8], ) -> Result<EccResultHandle<'op, AffinePointVerificationAndMultiplication>, KeyLengthMismatch>

Base Point Verification and Multiplication

This operation verifies whether Point (Px, Py) is on the selected elliptic curve and performs (Qx, Qy) = k * (Px, Py).

Errors

This function will return an error if the bitlength of the parameters is different from the bitlength of the prime fields of the curve.

pub fn jacobian_point_multiplication<'op>( &'op mut self, curve: EllipticCurve, k: &[u8], px: &[u8], py: &[u8], ) -> Result<EccResultHandle<'op, JacobianPointMultiplication>, KeyLengthMismatch>

Jacobian Point Multiplication

This operation performs (Qx, Qy, Qz) = k * (Px, Py, 1).

Errors

This function will return an error if the bitlength of the parameters is different from the bitlength of the prime fields of the curve.

pub fn jacobian_point_verification<'op>( &'op mut self, curve: EllipticCurve, qx: &[u8], qy: &[u8], qz: &[u8], ) -> Result<EccResultHandle<'op, JacobianPointVerification>, KeyLengthMismatch>

Jacobian Point Verification

This operation verifies whether Point (Qx, Qy, Qz) is on the selected elliptic curve.

Errors

This function will return an error if the bitlength of the parameters is different from the bitlength of the prime fields of the curve.

pub fn affine_point_verification_jacobian_multiplication<'op>( &'op mut self, curve: EllipticCurve, k: &[u8], px: &[u8], py: &[u8], ) -> Result<EccResultHandle<'op, AffinePointVerificationAndJacobianPointMultiplication>, KeyLengthMismatch>

Base Point Verification + Jacobian Point Multiplication

This operation first verifies whether Point (Px, Py) is on the selected elliptic curve. If yes, it performs (Qx, Qy, Qz) = k * (Px, Py, 1).

Errors

This function will return an error if the bitlength of the parameters is different from the bitlength of the prime fields of the curve.