EccBackend

Struct EccBackend 

pub struct EccBackend<'d> { /* private fields */ }
ECC processing backend.

This struct enables shared access to the device’s ECC hardware using a work queue.

Implementations

Source

impl<'d> EccBackend<'d>

pub fn new(ecc: ECC<'d>, config: Config) -> Self

Creates a new ECC backend.

The backend needs to be started before it can execute ECC operations.

pub fn start(&mut self) -> EccWorkQueueDriver<'_, 'd>

Registers the ECC driver to process ECC operations.

The driver stops operating when the returned object is dropped.