EccBackendOperation

Struct EccBackendOperation 

pub struct EccBackendOperation<'op, O: EccOperation> { /* private fields */ }
An ECC operation that can be enqueued on the work queue.

Implementations

Source

impl<'op, O: EccOperation> EccBackendOperation<'op, O>

pub fn with_scalar_result( self, out: &'op mut [u8], ) -> Result<Self, KeyLengthMismatch>

Designate a buffer for the scalar result of the operation.

Once the operation is processed, the result can be retrieved from the designated buffer.

Errors

Returns an error if out is not the correct size.

pub fn with_affine_point_result( self, px: &'op mut [u8], py: &'op mut [u8], ) -> Result<Self, KeyLengthMismatch>

Designate buffers for the affine point result of the operation.

Once the operation is processed, the result can be retrieved from the designated buffers.

Errors

Returns an error if x or y are not the correct size.

pub fn with_jacobian_point_result( self, qx: &'op mut [u8], qy: &'op mut [u8], qz: &'op mut [u8], ) -> Result<Self, KeyLengthMismatch>

Designate buffers for the Jacobian point result of the operation.

Once the operation is processed, the result can be retrieved from the designated buffers.

Errors

Returns an error if x, y, or z are not the correct size.

pub fn point_on_curve(&self) -> bool

Returns true if the input point is on the curve.

The operation must be processed before this method returns a meaningful value.

pub fn process(&mut self) -> EccHandle<'_>

Starts processing the operation.

The returned EccHandle must be polled to completion before the operation is considered complete.