pub struct EccBackend<'d> { /* private fields */ }Expand description
ECC processing backend.
This struct enables shared access to the device’s ECC hardware using a work queue.
Implementations
Sourceimpl<'d> EccBackend<'d>
impl<'d> EccBackend<'d>
Sourcepub fn new(ecc: ECC<'d>, config: Config) -> Self
pub fn new(ecc: ECC<'d>, config: Config) -> Self
Creates a new ECC backend.
The backend needs to be started before it can execute ECC operations.
Sourcepub fn start(&mut self) -> EccWorkQueueDriver<'_, 'd>
pub fn start(&mut self) -> EccWorkQueueDriver<'_, 'd>
Registers the ECC driver to process ECC operations.
The driver stops operating when the returned object is dropped.