pub struct EccBackendOperation<'op, O: EccOperation> { /* private fields */ }Expand description
An ECC operation that can be enqueued on the work queue.
Implementations
Sourceimpl<'op, O: EccOperation> EccBackendOperation<'op, O>
impl<'op, O: EccOperation> EccBackendOperation<'op, O>
Sourcepub fn with_scalar_result(
self,
out: &'op mut [u8],
) -> Result<Self, KeyLengthMismatch>where
O: OperationReturnsScalar,
pub fn with_scalar_result(
self,
out: &'op mut [u8],
) -> Result<Self, KeyLengthMismatch>where
O: OperationReturnsScalar,
Designate a buffer for the scalar result of the operation.
Once the operation is processed, the result can be retrieved from the designated buffer.
Errors
Returns an error if out is not the correct size.
Sourcepub fn with_affine_point_result(
self,
px: &'op mut [u8],
py: &'op mut [u8],
) -> Result<Self, KeyLengthMismatch>where
O: OperationReturnsAffinePoint,
pub fn with_affine_point_result(
self,
px: &'op mut [u8],
py: &'op mut [u8],
) -> Result<Self, KeyLengthMismatch>where
O: OperationReturnsAffinePoint,
Designate buffers for the affine point result of the operation.
Once the operation is processed, the result can be retrieved from the designated buffers.
Errors
Returns an error if x or y are not the correct size.
Sourcepub fn with_jacobian_point_result(
self,
qx: &'op mut [u8],
qy: &'op mut [u8],
qz: &'op mut [u8],
) -> Result<Self, KeyLengthMismatch>where
O: OperationReturnsJacobianPoint,
pub fn with_jacobian_point_result(
self,
qx: &'op mut [u8],
qy: &'op mut [u8],
qz: &'op mut [u8],
) -> Result<Self, KeyLengthMismatch>where
O: OperationReturnsJacobianPoint,
Designate buffers for the Jacobian point result of the operation.
Once the operation is processed, the result can be retrieved from the designated buffers.
Errors
Returns an error if x, y, or z are not the correct size.
Sourcepub fn point_on_curve(&self) -> boolwhere
O: OperationVerifiesPoint,
pub fn point_on_curve(&self) -> boolwhere
O: OperationVerifiesPoint,
Returns true if the input point is on the curve.
The operation must be processed before this method returns a meaningful value.